.. :changelog:

History
-------

0.1.0 (2019-03-16)
++++++++++++++++++

* First release on PyPI. No tests are present, use at your own risk!


0.2.0 (2019-03-07)
++++++++++++++++++

* Add support for x-www-form-urlencoded content
* Improved JS for admin form
* Auto-add content-type header
* Added better HTTP request/response records.
